package
Version:
v0.0.0-...-f991725
Opens a new window with list of versions in this module.
Published: Mar 21, 2014
License: LGPL-3.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CalcPaddedCapacity(original_length int, b byte) (padded_capacity int)
XorDecode recovers original data_block from chunks given
XorEncode takes a data_block as input and produces b + 1 chunks from it
Original data block can then be recovered from any of b chunks
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.